# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

%bcond_without examples

# Versioning

%define qtmajor 6
%define qtminor 7
%define qtsubminor 3
%define qtversion  %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir  qtgraphs-everywhere-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqtgraphs   %mklibname qt%{qtmajor}graphs %{qtmajor}
%define libqtgraphs_d %mklibname qt%{qtmajor}graphs -d

Name:           qtgraphs6
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Graphs component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
#Branch Patchs

#Trunk Patchs

#Patch from Mageia

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6OpenGL)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6QuickShapesPrivate)
BuildRequires:  cmake(Qt6QuickTest)
BuildRequires:  cmake(Qt6QuickWidgets)
BuildRequires:  cmake(Qt6Quick3D)
BuildRequires:  cmake(Qt6Test)

BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(vulkan)

Provides:       qt%{qtmajor}-qtgraphs = %{version}-%{release}

%description
Qt%{qtmajor} Graphs component.

%files
%license LICENSES/*
%{_qt6_qmldir}/QtGraphs/

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        QtGraphs%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools6
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools6-assistant
Recommends:     qttools6-assistant

%description doc
Documentation for APIs and tools in QtGraphs%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt6_docdir}/qtgraphs.qch
%{_qt6_docdir}/qtgraphs/
%endif

#------------------------------------------------------------------------------

%package -n     %{libqtgraphs}
Summary:        Qt%{qtmajor} Graphs Library
Group:          System/Libraries

%description -n %{libqtgraphs}
Qt%{qtmajor} Graphs Component Library.

%files -n %{libqtgraphs}
%{_qt6_libdir}/libQt6Graphs.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n     %{libqtgraphs_d}
Summary:        Devel files needed to build apps based on Qt Graphs
Group:          Development/KDE and Qt
Requires:       qtgraphs6 = %version
Requires:       %{libqtgraphs} = %version
Provides:       libqtgraphs6-devel = %version
Provides:       libqt6graphs-devel = %version
Provides:       qtgraphs6-devel = %version
Provides:       qt6graphs-devel = %version

Provides:       libqtgraphs6-private-devel = %version
Provides:       libqt6graphs-private-devel = %version
Provides:       qtgraphs6-private-devel = %version
Provides:       qt6graphs-private-devel = %version

%description -n %{libqtgraphs_d}
Devel files needed to build apps based on Qt Graphs.

%files -n %{libqtgraphs_d}
%{_qt6_headerdir}/QtGraphs/
%{_qt6_libdir}/libQt6Graphs.so
%{_qt6_libdir}/libQt6Graphs.prl
%{_qt6_libdir}/cmake/Qt6Graphs/
%{_qt6_archdatadir}/mkspecs/modules/qt_lib_graphs*.pri
%{_qt6_libdir}/qt6/metatypes/qt6*_metatypes.json
%{_qt6_libdir}/qt6/modules/Graphs.json
%{_qt6_libdir}/pkgconfig/Qt6Graphs.pc
%if %{with examples}
%{_qt6_examplesdir}/graphs/
%endif
#
%{_qt6_libdir}/cmake/Qt6Qml/QmlPlugins/Qt6Graphsplugin*.cmake
%{_qt6_libdir}/cmake/Qt6BuildInternals/StandaloneTests/QtGraphsTestsConfig.cmake

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qtgraphs-everywhere-src-%{qtversion}

%build
%cmake_qt6 %{!?with_examples:-DQT_BUILD_EXAMPLES:BOOL=OFF}
%cmake_build

%if %{build_docs}
%ninja_build -C build docs
%endif

%install
%cmake_install

%if %{build_docs}
%ninja_install -C build install_docs
%endif


%changelog
* Sat Oct 05 2024 daviddavid <daviddavid> 6.7.3-1.mga10
+ Revision: 2103606
- New version 6.7.3
- enable docs building

* Wed Jul 31 2024 daviddavid <daviddavid> 6.7.2-1.mga10
+ Revision: 2083103
- New version 6.7.2

* Tue Jun 11 2024 daviddavid <daviddavid> 6.7.1-2.mga10
+ Revision: 2072565
- rebuild for 'Qt_$MAJOR_PRIVATE_API' settings

* Thu May 23 2024 daviddavid <daviddavid> 6.7.1-1.mga10
+ Revision: 2066797
- New version 6.7.1

* Thu Feb 15 2024 daviddavid <daviddavid> 6.6.2-1.mga10
+ Revision: 2041623
- New version 6.6.2

* Sun Oct 22 2023 daviddavid <daviddavid> 6.6.0-1.mga10
+ Revision: 2000055
- initial package qtgraphs6

